```
    ___________.._______
    | .__________))______|
    | | / /      ||
    | |/ /       ||
    | | /        ||.-''.
    | |/         |/  _  \
    | |          ||  `/,|
    | |          (\\`_.'
    | |         .-`--'.
    | |        /Y . . Y\
    | |       // |   | \\
    | |      //  | . |  \\
    | |     ')   |   |   (`
    | |          ||'||
    | |          || ||
    | |          || ||
    | |          || ||
    | |         / | | \
    """"""""""|_`-' `-' |"""|
    |"|"""""""\ \       '"|"|
    | |        \ \        | |
    : :         \ \       : :  Hangman
    . .          `'       . .
```

[![Maintenance](https://img.shields.io/maintenance/yes/2018.svg)]() [![License](https://img.shields.io/github/license/chrisenytc/hangman.svg)](https://github.com/chrisenytc/hangman/blob/master/LICENSE) ![PyPI](https://img.shields.io/pypi/v/hangman-game.svg)
![PyPI - Downloads](https://img.shields.io/pypi/dm/hangman-game.svg)
[![Twitter Follow](https://img.shields.io/twitter/follow/chrisenytc.svg?style=social&label=Follow)](http://twitter.com/chrisenytc) [![Twitter URL](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?text=Awesome%20https://github.com/chrisenytc/hangman%20via%20@chrisenytc)

> A CLI game built with Python

# Installation

```bash
$ pip install hangman-game
```

# Getting Started

```bash
$ hangman
```

## Contributing

Bug reports and pull requests are welcome on GitHub at [https://github.com/chrisenytc/hangman](https://github.com/chrisenytc/hangman). This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

1. Fork it [chrisenytc/hangman](https://github.com/chrisenytc/hangman/fork)
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am "Add some feature"`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create new Pull Request

## Support

If you have any problem or suggestion please open an issue [here](https://github.com/chrisenytc/hangman/issues).

## License

Check [here](LICENSE).
